Index: remoting/host/video_scheduler.h |
diff --git a/remoting/host/video_scheduler.h b/remoting/host/video_scheduler.h |
index 3bcf27723f9d64f08ad97ba9d9c08e3c784dfbe0..215def01e007b6eaf40cbb5083de3d775a3a9e9e 100644 |
--- a/remoting/host/video_scheduler.h |
+++ b/remoting/host/video_scheduler.h |
@@ -33,13 +33,13 @@ class CursorShapeInfo; |
namespace protocol { |
class CursorShapeInfo; |
class CursorShapeStub; |
-class VideoStub; |
+class VideoSender; |
} // namespace protocol |
// Class responsible for scheduling frame captures from a |
// webrtc::DesktopCapturer, delivering them to a VideoEncoder to encode, and |
// finally passing the encoded video packets to the specified VideoStub to send |
// on the network. |
// |
// THREADING |
// |
@@ -92,7 +92,7 @@ class VideoScheduler : public base::RefCountedThreadSafe<VideoScheduler>, |
scoped_ptr<webrtc::MouseCursorMonitor> mouse_cursor_monitor, |
scoped_ptr<VideoEncoder> encoder, |
protocol::CursorShapeStub* cursor_stub, |
- protocol::VideoStub* video_stub); |
+ protocol::VideoSender* video_stub); |
// webrtc::DesktopCapturer::Callback implementation. |
webrtc::SharedMemory* CreateSharedMemory(size_t size) override; |
@@ -189,7 +189,7 @@ class VideoScheduler : public base::RefCountedThreadSafe<VideoScheduler>, |
// Interfaces through which video frames and cursor shapes are passed to the |
// client. These members are always accessed on the network thread. |
protocol::CursorShapeStub* cursor_stub_; |
- protocol::VideoStub* video_stub_; |
+ protocol::VideoSender* video_sender_; |
// Timer used to schedule CaptureNextFrame(). |
scoped_ptr<base::OneShotTimer<VideoScheduler> > capture_timer_; |
@@ -33,13 +33,13 @@ class CursorShapeInfo; |
// Class responsible for scheduling frame captures from a |
// webrtc::DesktopCapturer, delivering them to a VideoEncoder to encode, and |
-// finally passing the encoded video packets to the specified VideoStub to send |
-// on the network. |
+// finally passing the encoded video packets to the specified VideoSender to |
+// send on the network. |
// |
// THREADING |